pub struct LegacyRandomSplitter {
seed: i64,
}Expand description
A positional random number generator factory for the legacy Minecraft LCG algorithm. This can create random sources based on position, hash, or seed.
Fields
seed: i64Implementations